@@ -27,7 +27,7 @@
 
 package Config::Model::Backend::Any ;
 BEGIN {
-  $Config::Model::Backend::Any::VERSION = '1.238';
+  $Config::Model::Backend::Any::VERSION = '1.240';
 }
 
 use Carp;
@@ -167,7 +167,7 @@ sub write_data_and_comments {
     return $res ;
 }
 
-no Moose ;
+no Any::Moose ;
 __PACKAGE__->meta->make_immutable ;
 
 1;
@@ -180,7 +180,7 @@ Config::Model::Backend::Any - Virtual class for other backends
 
 =head1 VERSION
 
-version 1.238
+version 1.240
 
 =head1 SYNOPSIS
 
@@ -248,7 +248,7 @@ version 1.238
     return 1;
  }
 
- no Moose ;
+ no Any::Moose ;
  __PACKAGE__->meta->make_immutable ;
 
 =head1 DESCRIPTION
